package com.jiuqi.dna.ide.designer.elements;

import java.util.ArrayList;
import java.util.Iterator;

/* loaded from: com_jiuqi_dna_ide_designer_elements.jar:com/jiuqi/dna/ide/designer/elements/CompositeElement.class */
public class CompositeElement extends FigureElement implements ICompositeElement {
    private static final long serialVersionUID = 8855255756753548280L;
    private ILayoutElement layout;
    private ArrayList<IFigureElement> figureChildren = new ArrayList<>();
    private ArrayList<IDesignerElement> nonFigureChildren = new ArrayList<>();

    @Override // com.jiuqi.dna.ide.designer.elements.FigureElement, com.jiuqi.dna.ide.designer.elements.DesignerElement, com.jiuqi.dna.ide.designer.elements.IDesignerElement
    public void dispose() {
        if (!isInitialized()) {
            return;
        }
        Iterator<ILinkElement> it = getSourceLinks().iterator();
        while (it.hasNext()) {
            ILinkElement link = it.next();
            link.dispose();
        }
        Iterator<ILinkElement> it2 = getTargetLinks().iterator();
        while (it2.hasNext()) {
            ILinkElement link2 = it2.next();
            link2.dispose();
        }
        Iterator<IDesignerElement> it3 = getChildren().iterator();
        while (it3.hasNext()) {
            IDesignerElement elem = it3.next();
            elem.dispose();
        }
        this.parent.removeChild(this);
        fireDelete();
        setInitialized(false);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public void addChild(IDesignerElement child) {
        if (child instanceof IFigureElement) {
            if (this.figureChildren.contains((IFigureElement) child)) {
                return;
            } else {
                this.figureChildren.add((IFigureElement) child);
            }
        } else if (this.nonFigureChildren.contains(child)) {
            return;
        } else {
            this.nonFigureChildren.add(child);
        }
        fireAddChild(child);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public void addChild(int index, IDesignerElement child) {
        if (child instanceof IFigureElement) {
            if (this.figureChildren.contains((IFigureElement) child)) {
                return;
            } else {
                this.figureChildren.add(index, (IFigureElement) child);
            }
        } else if (this.nonFigureChildren.contains(child)) {
            return;
        } else {
            this.nonFigureChildren.add(index, child);
        }
        fireAddChild(child);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public int getChildIndex(IDesignerElement child) {
        if (child instanceof IFigureElement) {
            return this.figureChildren.indexOf(child);
        }
        return this.nonFigureChildren.indexOf(child);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public IFigureElement getFigureChild(int index) {
        return this.figureChildren.get(index);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public int getFigureChildSize() {
        return this.figureChildren.size();
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public ArrayList<IDesignerElement> getChildren() {
        ArrayList<IDesignerElement> children = new ArrayList<>();
        children.addAll(this.figureChildren);
        children.addAll(this.nonFigureChildren);
        return children;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public ArrayList<IFigureElement> getFigureChildren() {
        return this.figureChildren;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public ArrayList<IDesignerElement> getNonFigureChildren() {
        return this.nonFigureChildren;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public <T extends IDesignerElement> ArrayList<T> getChildren(Class<T> cls) {
        ArrayList<T> arrayList = (ArrayList<T>) new ArrayList();
        Iterator<IDesignerElement> it = getChildren().iterator();
        while (it.hasNext()) {
            IDesignerElement next = it.next();
            if (next.getClass() == cls) {
                arrayList.add(next);
            }
        }
        return arrayList;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public ArrayList<IDesignerElement> getAllChildren() {
        ArrayList<IDesignerElement> children = getChildren();
        ArrayList<IDesignerElement> list = new ArrayList<>(children);
        Iterator<IDesignerElement> it = children.iterator();
        while (it.hasNext()) {
            IDesignerElement child = it.next();
            if (child instanceof ICompositeElement) {
                ICompositeElement elem = (ICompositeElement) child;
                list.addAll(elem.getAllChildren());
            }
        }
        return list;
    }

    /* JADX WARN: Multi-variable type inference failed */
    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public <T extends IDesignerElement> ArrayList<T> getAllChildren(Class<T> cls) {
        ArrayList<T> arrayList = (ArrayList<T>) new ArrayList();
        Iterator<IDesignerElement> it = getChildren().iterator();
        while (it.hasNext()) {
            IDesignerElement next = it.next();
            if (next.getClass() == cls) {
                arrayList.add(next);
            }
            if (next instanceof ICompositeElement) {
                arrayList.addAll(((ICompositeElement) next).getAllChildren(cls));
            }
        }
        return arrayList;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public void removeChild(IDesignerElement child) {
        if (child instanceof IFigureElement) {
            if (this.figureChildren.contains((IFigureElement) child)) {
                this.figureChildren.remove((IFigureElement) child);
                fireRemoveChild(child);
                return;
            }
            return;
        }
        if (this.nonFigureChildren.contains(child)) {
            this.nonFigureChildren.remove(child);
            fireRemoveChild(child);
        }
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public boolean canAcceptAsChild(IDesignerElement child) {
        return fireVerifyAddChild(child);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public boolean canRemoveChild(IDesignerElement child) {
        return fireVerifyRemoveChild(child);
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public ILayoutElement getLayout() {
        return this.layout;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public void setLayout(ILayoutElement layout) {
        this.layout = layout;
        fireChangeLayout();
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public IFigureElement findElement(int x, int y) {
        if (!containsPoint(x, y)) {
            return null;
        }
        Iterator<IFigureElement> it = this.figureChildren.iterator();
        while (it.hasNext()) {
            IDesignerElement elem = it.next();
            if (elem.isVisible()) {
                IFigureElement fElem = (IFigureElement) elem;
                if (fElem.containsPoint(x, y)) {
                    if (fElem instanceof ICompositeElement) {
                        ICompositeElement cElem = (ICompositeElement) fElem;
                        return cElem.findElement(x - getBounds().x, y - getBounds().y);
                    }
                    return fElem;
                }
            }
        }
        return this;
    }

    @Override // com.jiuqi.dna.ide.designer.elements.ICompositeElement
    public IDesignerElement getDesignerElement(String id) {
        if (id == null) {
            return null;
        }
        Iterator<IDesignerElement> it = getChildren().iterator();
        while (it.hasNext()) {
            IDesignerElement elem = it.next();
            if (id.equals(elem.getId())) {
                return elem;
            }
            if (elem instanceof ICompositeElement) {
                ICompositeElement cElem = (ICompositeElement) elem;
                IDesignerElement dElem = cElem.getDesignerElement(id);
                if (dElem != null) {
                    return dElem;
                }
            }
        }
        return null;
    }

    protected void fireAddChild(IDesignerElement child) {
        if (this.designer != null && isInitialized()) {
            this.designer.fireCompositeAddChild(this, child);
        }
    }

    protected void fireRemoveChild(IDesignerElement child) {
        if (this.designer != null && isInitialized()) {
            this.designer.fireCompositeRemoveChild(this, child);
        }
    }

    protected void fireChangeLayout() {
        if (this.designer != null && isInitialized()) {
            this.designer.fireCompositeChangeLayout(this);
        }
    }

    protected boolean fireVerifyAddChild(IDesignerElement child) {
        if (this.designer != null && isInitialized()) {
            return this.designer.fireVerifyCompositeAddChild(this, child);
        }
        return true;
    }

    protected boolean fireVerifyRemoveChild(IDesignerElement child) {
        if (this.designer != null && isInitialized()) {
            return this.designer.fireVerifyCompositeRemoveChild(this, child);
        }
        return true;
    }
}
